/*
 * file: pv_minmax.h
 * This file is part of the libpv library.
 *
 * Copyright 2005 Pengutronix
 *
 * Please send bug reports to bugs@pengutronix.de
 *
 * See COPYING for the status of this software.
 */

#ifndef PV_MINMAX_H
#define PV_MINMAX_H

#include <libpv_config.h>

#include <inttypes.h>

#include <pv_types.h>
#include <pv_register.h>

static inline int pv_has_min	(const struct pv_engine	*engine,
				 const struct pv	*pv)
{
	return pv->has_min;
}

static inline int pv_has_max	(const struct pv_engine	*engine,
				 const struct pv	*pv)
{
	return pv->has_max;
}

/************** min ****************/

static inline uint8_t pv_get_min_uint8	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->min.u8;
}

static inline int8_t pv_get_min_int8	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->min.s8;
}

static inline uint16_t pv_get_min_uint16	(const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return pv->min.u16;
}

static inline int16_t pv_get_min_int16	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->min.s16;
}

static inline uint32_t pv_get_min_uint32	(const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return pv->min.u32;
}

static inline int32_t pv_get_min_int32	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->min.s32;
}

static inline uint64_t pv_get_min_uint64	(const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return pv->min.u64;
}

static inline int64_t pv_get_min_int64	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->min.s64;
}

static inline float pv_get_min_float	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->min.f;
}

static inline double pv_get_min_double	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->min.d;
}

/************** max ****************/

static inline uint8_t pv_get_max_uint8	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->max.u8;
}

static inline int8_t pv_get_max_int8	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->max.s8;
}

static inline uint16_t pv_get_max_uint16	(const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return pv->max.u16;
}

static inline int16_t pv_get_max_int16	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->max.s16;
}

static inline uint32_t pv_get_max_uint32	(const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return pv->max.u32;
}

static inline int32_t pv_get_max_int32	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->max.s32;
}

static inline uint64_t pv_get_max_uint64	(const struct pv_engine	*engine,
						 const struct pv	*pv)
{
	return pv->max.u64;
}

static inline int64_t pv_get_max_int64	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->max.s64;
}

static inline float pv_get_max_float	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->max.f;
}

static inline double pv_get_max_double	(const struct pv_engine	*engine,
					 const struct pv	*pv)
{
	return pv->max.d;
}

#endif	/* !PV_MINMAX_H */
